@@ -1,28 +1,22 @@
-/* $Id: xfce-rc.c 817 2004-05-14 20:51:06Z benny $ */
+/* $Id: xfce-rc.c 21064 2006-04-18 19:35:58Z benny $ */
 /*-
- * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
- * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
- * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
- * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -48,8 +42,12 @@
 #include <string.h>
 #endif
 
+
+
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4util/xfce-rc-private.h>
+#include <libxfce4util/libxfce4util-alias.h>
+
 
 
 /* called by _xfce_rc_{simple,config}_new */
@@ -74,6 +72,7 @@ _xfce_rc_init (XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_simple_open:
  * @filename : name of the filename to open.
@@ -120,6 +119,7 @@ xfce_rc_simple_open (const gchar *filename,
 }
 
 
+
 /**
  * xfce_rc_config_open:
  * @type     :
@@ -143,6 +143,7 @@ xfce_rc_config_open (XfceResourceType type,
 }
 
 
+
 /**
  * xfce_rc_close:
  * @rc : an #XfceRc object.
@@ -171,6 +172,7 @@ xfce_rc_close (XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_flush:
  * @rc : an #XfceRc object.
@@ -191,6 +193,7 @@ xfce_rc_flush (XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_rollback:
  * @rc : an #XfceRc object.
@@ -211,6 +214,7 @@ xfce_rc_rollback (XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_is_dirty:
  * @rc : an #XfceRc object.
@@ -233,6 +237,7 @@ xfce_rc_is_dirty (const XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_is_readonly:
  * @rc : an #XfceRc object.
@@ -255,6 +260,7 @@ xfce_rc_is_readonly (const XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_get_locale:
  * @rc : an #XfceRc object.
@@ -277,6 +283,7 @@ xfce_rc_get_locale (const XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_get_groups:
  * @rc : an #XfceRc object.
@@ -302,6 +309,7 @@ xfce_rc_get_groups (const XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_get_entries:
  * @rc    : an #XfceRc object.
@@ -331,6 +339,7 @@ xfce_rc_get_entries (const XfceRc *rc, const gchar *group)
 }
 
 
+
 /**
  * xfce_rc_delete_group:
  * @rc     : an #XfceRc object.
@@ -359,6 +368,7 @@ xfce_rc_delete_group (XfceRc *rc, const gchar *group, gboolean global)
 }
 
 
+
 /**
  * xfce_rc_get_group:
  * @rc : an #XfceRc object.
@@ -381,6 +391,7 @@ xfce_rc_get_group (const XfceRc *rc)
 }
 
 
+
 /**
  * xfce_rc_has_group:
  * @rc    : an #XfceRc object.
@@ -402,6 +413,7 @@ xfce_rc_has_group (const XfceRc *rc, const gchar *group)
 }
 
 
+
 /**
  * xfce_rc_set_group:
  * @rc    : an #XfceRc object.
@@ -426,6 +438,7 @@ xfce_rc_set_group (XfceRc *rc, const gchar *group)
 }
 
 
+
 /**
  * xfce_rc_delete_entry:
  * @rc     : an #XfceRc object.
@@ -448,6 +461,7 @@ xfce_rc_delete_entry (XfceRc *rc, const gchar *key, gboolean global)
 }
 
 
+
 /**
  * xfce_rc_has_entry:
  * @rc  : an #XfceRc object.
@@ -472,6 +486,7 @@ xfce_rc_has_entry (const XfceRc *rc, const gchar *key)
 }
 
 
+
 /**
  * xfce_rc_read_entry:
  * @rc       : an #XfceRc object.
@@ -500,6 +515,7 @@ xfce_rc_read_entry (const XfceRc *rc, const gchar *key, const gchar *fallback)
 }
 
 
+
 /**
  * xfce_rc_read_entry_untranslated:
  * @rc       : an #XfceRc object.
@@ -532,6 +548,7 @@ xfce_rc_read_entry_untranslated (const XfceRc *rc,
 }
 
 
+
 /**
  * xfce_rc_read_bool_entry:
  * @rc       : an #XfceRc object.
@@ -563,6 +580,7 @@ xfce_rc_read_bool_entry (const XfceRc *rc, const gchar *key, gboolean fallback)
 }
 
 
+
 /**
  * xfce_rc_read_int_entry:
  * @rc       : an #XfceRc object.
@@ -599,6 +617,7 @@ xfce_rc_read_int_entry (const XfceRc *rc, const gchar *key, gint fallback)
 }
 
 
+
 /**
  * xfce_rc_read_list_entry:
  * @rc        : an #XfceRc object.
@@ -631,6 +650,7 @@ xfce_rc_read_list_entry (const XfceRc *rc, const gchar *key, const gchar *delimi
 }
 
 
+
 /**
  * xfce_rc_write_entry:
  * @rc    : an #XfceRc object.
@@ -659,6 +679,7 @@ xfce_rc_write_entry (XfceRc *rc, const gchar *key, const gchar *value)
 }
 
 
+
 /**
  * xfce_rc_write_bool_entry:
  * @rc    : an #XfceRc object.
@@ -676,6 +697,7 @@ xfce_rc_write_bool_entry (XfceRc *rc, const gchar *key, gboolean value)
 }
 
 
+
 /**
  * xfce_rc_write_int_entry:
  * @rc    : an #XfceRc object.
@@ -696,6 +718,7 @@ xfce_rc_write_int_entry (XfceRc *rc, const gchar *key, gint value)
 }
 
 
+
 /**
  * xfce_rc_write_list_entry:
  * @rc        : an #XfceRc object.
@@ -727,6 +750,5 @@ xfce_rc_write_list_entry (XfceRc      *rc,
 
 
 
-
-
-
+#define __XFCE_RC_C__
+#include <libxfce4util/libxfce4util-aliasdef.c>
